#ifndef STROPS_H
#define STROPS_H

#include <stddef.h>

/*
    Functions that return char*, return a new heap-allocated string.
    The user of this library is responsible for freeing the memory of the result.
    Only 7-Bit Ascii is supported.
*/

typedef unsigned long long ull_t;

char contains_char(const char* string, char char_to_search);
char contains_string(const char* string, const char* string_to_search);

char* strops_to_lowercase(const char* string);
char* strops_to_uppercase(const char* string);
int strops_is_lowercase(const char* string);
int strops_is_uppercase(const char* string);

char* strops_insert_at_pos_string(const char* string, const char* string_to_insert, ull_t pos);
char* strops_remove_at_pos_char(const char* string, ull_t pos);
void strops_remove_at_pos_char_inplace(char* string, ull_t pos);

char* strops_trim_right_whitespace(const char* string);
char* strops_trim_left_whitespace(const char* string);
char* strops_trim_both_whitespace(const char* string);

char* strops_trim_right_chars(const char* string, const char* chars_to_remove);
char* strops_trim_left_chars(const char* string, const char* chars_to_remove);
char* strops_trim_both_chars(const char* string, const char* chars_to_remove);

char* strops_trim_right_string(const char* string, const char* string_to_remove);
char* strops_trim_left_string(const char* string, const char* string_to_remove);
char* strops_trim_both_string(const char* string, const char* string_to_remove);

char* strops_remove_chars(const char* string, const char* chars_to_remove);
char* strops_remove_string(const char* string, const char* string_to_remove);

ull_t strops_word_count(const char* string);

#endif /* STROPS_H */

